@@ -20,9 +20,13 @@
 #ifndef APPLICATION_H
 #define APPLICATION_H
 
-#include <KUniqueApplication>
+// Qt
+#include <QApplication>
+
+// Utils
 #include <utils/d_ptr.h>
 
+
 class Resources;
 class Activities;
 class Features;
@@ -30,27 +34,34 @@ class Features;
 /**
  * Main application object
  */
-class Application: public KUniqueApplication {
+class Application : public QApplication {
     Q_OBJECT
 
 public:
-    Application();
+    Application(int &argc, char **argv);
     virtual ~Application();
 
     virtual int newInstance();
 
-    static Application * self();
-    static void quit();
+    // static Application * self();
+    // static void quit();
 
-    Resources  & resources()  const;
-    Activities & activities() const;
-    Features   & features()   const;
+    Resources &resources() const;
+    Activities &activities() const;
+    Features &features() const;
+
+public Q_SLOTS:
+    void quit();
+    QString serviceVersion() const;
 
 private Q_SLOTS:
+    void init();
     void loadPlugins();
 
 private:
     D_PTR;
+
+    friend int main(int, char**);
 };
 
 #endif // APPLICATION_H
